/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.0
 *
 *********************************************************************
 * FileName:        main.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"                        // Required

#include "io_cfg.h"                                 // Required
#include "timers.h"                                 // Required
#include <usart.h> 

#include "system\usb\usb_compile_time_validation.h" // Optional
#include "user\user.h"                        // Modifiable
#include "command.h"

#define true 1
#define false 0
#define MAX_GRAPHICS 40

extern int PicCLK;
int k=0;

unsigned char digit,row;
unsigned char CHAR_x [8];
int debug=0;
int debug1=0;

int Timer_interrupt_count=0;
int Display_counter=0;

unsigned char RX_cmd,RX_data=0;  

unsigned char HeureDizaine = '-';
unsigned char HeureUnit ='-';

unsigned char MinuteDizaine ='-';
unsigned char MinuteUnit ='-';

unsigned char SecondeDizaine ='-';
unsigned char SecondeUnit ='-';

unsigned char bComputeTime = true;
unsigned char bGraphics = false;
unsigned char index=0;
unsigned char Graphics_data_index=0;

unsigned char Graphics [MAX_GRAPHICS];

// RS232 COMMANDS DEFINES
#define SET_CHAR_0 				0x01
#define SET_CHAR_1 				0x02
#define SET_CHAR_2 				0x03
#define SET_CHAR_3 				0x04
#define SET_CHAR_4 				0x05
#define SET_CHAR_5 				0x06
#define SET_CHAR_6 				0x07
#define SET_CHAR_7				0x08
#define SET_HEURE_DIZAINE		0x09
#define SET_HEURE_UNIT			0x0A
#define SET_MINUTE_DIZAINE		0x0B
#define SET_MINUTE_UNIT			0x0C
#define SET_SECONDE_DIZAINE		0x0D
#define SET_SECONDE_UNIT		0x0E
#define START_STOP_TIME_COMPUTE	0x0F
#define START_STOP_GRAPHICS		0x10
#define START_WRITE_GRAPHICS	0x11
#define DATA_WRITE_GRAPHICS		0x12
#define DISPLAY_ON_OFF			0x13
#define CHECK_SYNC				0x14
#define RESET				    0x15
#define GET_VERSION			    0x16

// DISPLAY GRAPHICS Defines
#define GRAPHICS_MODE 	2
#define TEXT_MODE 	0


/** V A R I A B L E S ********************************************************/
//#pragma udata

char Version [] = "FCALLBOX3 DISPLAY 5x7 V1.00\n\r";


/*; *************************************
; matrix 5x7 table 
; organisation char = 5 bytes (segment)
; to get a char segment , do a call MatrixTable with W = char-32 
; char code need to be -32 because of table does not show char bellow 32
; note that dt create a code equal to RETLW <data>
; segment data is returned in W
; *************************************
*/

rom const char MatrixTableSeg0 [] = {0x00, 0x00, 0x00, 0x28, 0x24, 0xC4, 0x6C, 0x00, 0x00, 0x00, 0x28, 0x10, 0x00, 0x10, 0x00, 0x04,
					       0x7C, 0x00, 0x42, 0x84, 0x18, 0xE4, 0x3C, 0x80, 0x6C, 0x60, 0x00, 0x00, 0x10, 0x28, 0x00, 0x40,
						   0x4C, 0x7E, 0xFE, 0x7C, 0xFE, 0xFE, 0xFE, 0x7C, 0xFE, 0x00, 0x04, 0xFE, 0xFE, 0xFE, 0xFE, 0x7C,
						   0xFE, 0x7C, 0xFE, 0x62, 0x80, 0xFC, 0xF8, 0xFC, 0xC6, 0xE0, 0x86, 0x00, 0x40, 0x00, 0x20, 0x02,
						   0x00, 0x04, 0xFE, 0x1C, 0x0C, 0x1C, 0x00, 0x12, 0xFE, 0x00, 0x04, 0x00, 0x00, 0x3E, 0x3E, 0x1C,
						   0x3E, 0x10, 0x3E, 0x12, 0x20, 0x3C, 0x38, 0x3C, 0x22, 0x20, 0x22, 0x00, 0x00, 0x82, 0x20, 0xA8};

rom const char MatrixTableSeg1 [] = {0x00, 0x00, 0xE0, 0xFE, 0x54, 0xC8, 0x92, 0xA0, 0x38, 0x82, 0x10, 0x10, 0x0A, 0x10, 0x06, 0x08,
						   0x8A, 0x42, 0x86, 0x82, 0x28, 0xA2, 0x52, 0x8E, 0x92, 0x92, 0x6C, 0x6A, 0x28, 0x28, 0x82, 0x80,
	                       0x92, 0x88, 0x92, 0x82, 0x82, 0x92, 0x90, 0x82, 0x10, 0x82, 0x02, 0x10, 0x02, 0x40, 0x20, 0x82,
	                       0x90, 0x82, 0x90, 0x92, 0x80, 0x02, 0x04, 0x02, 0x28, 0x10, 0x8A, 0xFE, 0x20, 0x82, 0x40, 0x02,
	                       0x80, 0x2A, 0x12, 0x22, 0x12, 0x2A, 0x10, 0x2A, 0x10, 0x00, 0x02, 0xFE, 0x82, 0x20, 0x10, 0x22,
	                       0x28, 0x28, 0x10, 0x2A, 0x20, 0x02, 0x04, 0x02, 0x14, 0x12, 0x26, 0x10, 0x00, 0x82, 0x40, 0x68};

rom const char MatrixTableSeg2 [] = {0x00, 0xF2, 0x00, 0x28, 0xFE, 0x10, 0xAA, 0xC0, 0x44, 0x44, 0x7C, 0x7C, 0x0C, 0x10, 0x06, 0x10,
						   0x92, 0xFE, 0x8A, 0xA2, 0x48, 0xA2, 0x92, 0x90, 0x92, 0x92, 0x6C, 0x6C, 0x44, 0x28, 0x44, 0x8A,
	 					   0x9E, 0x88, 0x92, 0x82, 0x82, 0x92, 0x90, 0x92, 0x10, 0xFE, 0x82, 0x28, 0x02, 0x30, 0x10, 0x82,
	 					   0x90, 0x8A, 0x98, 0x92, 0xFE, 0x02, 0x02, 0x0C, 0x10, 0x0E, 0x92, 0x82, 0x10, 0x82, 0x80, 0x02,
	 					   0x40, 0x2A, 0x12, 0x22, 0x12, 0x2A, 0x7E, 0x2A, 0x10, 0x5E, 0x02, 0x08, 0xFE, 0x1C, 0x20, 0x22,
	 					   0x28, 0x28, 0x20, 0x2A, 0xFC, 0x02, 0x02, 0x0C, 0x08, 0x0C, 0x2A, 0x6C, 0xEE, 0x6C, 0x40, 0x3E};

rom const char MatrixTableSeg3 [] ={0x00, 0x00, 0xE0, 0xFE, 0x54, 0x26, 0x44, 0x00, 0x82, 0x38, 0x10, 0x10, 0x00, 0x10, 0x00, 0x20,
						  0xA2, 0x02, 0x92, 0xD2, 0xFE, 0xA2, 0x92, 0xA0, 0x92, 0x94, 0x00, 0x00, 0x82, 0x28, 0x28, 0x90,
	   					  0x82, 0x88, 0x92, 0x82, 0x44, 0x92, 0x90, 0x92, 0x10, 0x82, 0xFC, 0x44, 0x02, 0x40, 0x08, 0x82,
	 					  0x90, 0x84, 0x94, 0x92, 0x80, 0x02, 0x04, 0x02, 0x28, 0x10, 0xA2, 0x82, 0x08, 0xFE, 0x40, 0x02,
	 					  0x20, 0x2A, 0x12, 0x22, 0x12, 0x2A, 0x90, 0x2A, 0x10, 0x00, 0xBC, 0x14, 0x02, 0x20, 0x20, 0x22,
	 					  0x28, 0x28, 0x20, 0x2A, 0x22, 0x02, 0x04, 0x02, 0x14, 0x10, 0x32, 0x82, 0x00, 0x10, 0x40, 0x68};

rom const char MatrixTableSeg4 [] ={0x00, 0x00, 0x00, 0x28, 0x48, 0x46, 0x0A, 0x00, 0x00, 0x00, 0x28, 0x10, 0x00, 0x10, 0x00, 0x40,
					      0x7C, 0x00, 0x62, 0x8C, 0x08, 0x9C, 0x0C, 0xC0, 0x6C, 0x78, 0x00, 0x00, 0x00, 0x28, 0x10, 0x60,
	 				      0x7C, 0x7E, 0x6C, 0x44, 0x38, 0x82, 0x80, 0x5E, 0xFE, 0x00, 0x80, 0x82, 0x02, 0xFE, 0xFE, 0x7C,
	 				      0x60, 0x7A, 0x62, 0x8C, 0x80, 0xFC, 0xF8, 0xFC, 0xC6, 0xE0, 0xC2, 0x00, 0x04, 0x00, 0x20, 0x02,
	 					  0x00, 0x1E, 0x0C, 0x22, 0xFE, 0x1A, 0x40, 0x3C, 0x0E, 0x00, 0x00, 0x22, 0x00, 0x3E, 0x1E, 0x1C,
	                      0x10, 0x3E, 0x10, 0x24, 0x24, 0x3C, 0x38, 0x3C, 0x22, 0x20, 0x22, 0x82, 0x00, 0x00, 0x80, 0xA8};


/** P R I V A T E  P R O T O T Y P E S ***************************************/
static void InitializeSystem(void);
void USBTasks(void);
void IT_Timer (void);
void SetC5   (void);
void ReSetC5 (void);
void SetC4   (void);
void ReSetC4 (void);
void SetC3   (void);
void ReSetC3 (void);
void SetC2   (void);
void ReSetC2 (void);
void SetC1   (void);
void ReSetC1 (void);
void SetCLR   (void);
void ReSetCLR (void);
void SetCLK   (void);
void ReSetCLK (void);
void SetDATA   (void);
void ReSetDATA (void);
void writeRow (unsigned char row,unsigned char data); 

void rx_handler (void) ;
void HighISR(void);
void compute_cmd(char cmd);
void put_string (char  *str);

/** V E C T O R  R E M A P P I N G *******************************************/

extern void _startup (void);        // See c018i.c in your C18 compiler dir
#pragma code _RESET_INTERRUPT_VECTOR = 0x000800
void _reset (void)
{
    _asm goto _startup _endasm
}
// FCALL IT TIMER

#pragma code JumpIT=0x08
void JumpIT (void)
{
_asm 
	goto HighISR
_endasm
}

#pragma code Low_IT = 0x18
void Low_IT (void)
{
_asm
	goto rx_handler
_endasm
}


#pragma code		//added to compile at office
#pragma interrupt rx_handler
void rx_handler  (void) 
{ 
  


} 

#pragma interrupt IT_Timer
void IT_Timer (void)
{
		if(INTCONbits.TMR0IF) //vrifie un dbordement sur TMR0
		{
			INTCONbits.TMR0IF = 0; // clear IT flag
	 		
            TMR0H = 0xFA;                                 // FA58 = 449.58Hz / FA59 = 499.91Hz FA5A = 500.25Hz
            TMR0L = 0x5A;                    
	        Timer_interrupt_count++;
			Display_counter++;

			/////////////////////
			// compute Display //
			/////////////////////
			if (Display_counter ==4)
			{
				Display_counter=0;
				
				if (bGraphics)	// graphics mode
				{
					// clear all rows
					SetC1();
					SetC2();
					SetC3();
					SetC4();
					SetC5();
	
					for (digit=0;digit<8;digit++)
						writeRow (row,Graphics [index++]); 
						
					row++;
				    if (row==6)
						row=0;
					if (index> (MAX_GRAPHICS))
						index=0;
				}
				else			// text mode
				{
			
			/*		SetC1();
					SetC2();
					SetC3();
					SetC4();
					SetC5();
		*/
					for (digit=0;digit<8;digit++)
						writeRow (row,CHAR_x[7-digit]); 



					row++;
				    if (row==5)
						row=0;
		
				}
			}
			///////////////////////////////////////
			// compute and update display buffer //
			///////////////////////////////////////

         	if (Timer_interrupt_count>=1000 && !bComputeTime) 
			{
				Timer_interrupt_count=0;
				
				//////////////////
				// compute time //
				//////////////////
				SecondeUnit++;				// increment second
				if (SecondeUnit>'9')			// increment dizaine of second
				{
					SecondeUnit = '0';
					SecondeDizaine++;
					if (SecondeDizaine>'5')		// incremente minute
					{
						SecondeDizaine='0';
						MinuteUnit++;
						if (MinuteUnit>'9')	// incremente dizaine of minute
						{
							MinuteUnit='0';
							MinuteDizaine++;
							if (MinuteDizaine>'5')		// incremente minute
							{
								MinuteDizaine='0';
								HeureUnit++;
									if (HeureDizaine=='0' && HeureUnit>'9')		// incremente heure 0h to 10h
									{
										HeureDizaine='1'; HeureUnit='0';
									}
									else 
									{
										if (HeureDizaine=='1' && HeureUnit>'9')		// incremente heure 10h to 19h
										{
											HeureDizaine='2'; HeureUnit ='0';
										}
										else
										if (HeureDizaine=='2' && HeureUnit>'3')		// incremente heure 20h to 24h
										{
											HeureDizaine ='0'; HeureUnit='0';
										}

									}

								
							}
						}
					}

						
				}

				////////////////////
				// update display //
				////////////////////

				CHAR_x [7] = SecondeUnit;
				CHAR_x [6] = SecondeDizaine;
				CHAR_x [5] = ':';
				CHAR_x [4] = MinuteUnit;
				CHAR_x [3] = MinuteDizaine;
				CHAR_x [2] = ':';
				CHAR_x [1] = HeureUnit;
				CHAR_x [0] = HeureDizaine;



			}
		}

		
}
#pragma interruptlow HighISR
void HighISR(void)
{
  char rcreg;
  char ferr;

 // Data from USART ?
   if (PIR1bits.RCIF && PIE1bits.RCIE)
   {
      // Read RCREG to clear RCIF
    
      ferr = RCSTAbits.FERR; // Read error flag
      rcreg = RCREG; // Read RX byte

      // Check for errors
      if (ferr || RCSTAbits.OERR)
      {
 		RCSTAbits.CREN=0;    //Overrun error (can be cleared by clearing bit CREN)
	    WREG=RCREG;    //clear Framing error 
      	RCSTAbits.CREN=1;
 		WriteUSART('H');
		// reset when uart error
		_asm 
			reset
		_endasm
      }
      else
      {
		compute_cmd(rcreg);
      }

      // Ensure to be immediately ready
      // in case a byte is received on USART
	 PIR1bits.RCIF=0;
      return ;
	}

	IT_Timer();
 }

#pragma code

/** D E C L A R A T I O N S **************************************************/
#pragma code
/******************************************************************************
 * Function:        void main(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Main program entry point.
 *
 * Note:            None
 *****************************************************************************/

void main(void)
{
    InitializeSystem();
	// set it timer
 	INTCON = 0x20;                //disable global and enable TMR0 interrupt
    INTCON2 = 0x84;               //TMR0 high priority
    RCONbits.IPEN = 1;            //enable priority levels
    TMR0H = 255;                  //clear timer
    TMR0L = 0;                    //clear timer
    T0CON = 0x82;                 //set up timer0 - prescaler 1:8
    INTCONbits.GIEH = 1;          //enable interrupts

	CHAR_x[0]=' ';
	CHAR_x[1]=' ';
	CHAR_x[2]='W';
	CHAR_x[3]='A';
	CHAR_x[4]='I';
	CHAR_x[5]='T';
	CHAR_x[6]=' ';
	CHAR_x[7]=' ';

	ReSetC5();
	ReSetC4();
	ReSetC3();
	ReSetC2();
	ReSetC1();
	ReSetCLR ();
	
	SetC1();
	SetC2();
	SetC3();
	SetC4();
	SetC5();
	SetCLR();

	// open serial port at 115200bps
	OpenUSART(USART_TX_INT_OFF & USART_RX_INT_ON & USART_ASYNCH_MODE & USART_EIGHT_BIT & USART_CONT_RX &
 	USART_BRGH_HIGH & USART_ADDEN_OFF, 12*2); // 38  
 	
   PIE1bits.RCIE = 1; // Enable reception interrupt..
   IPR1bits.RCIP = 1; // ..with high priority
   PIE1bits.TXIE = 0; // TX (later)..
   IPR1bits.TXIP = 1; // ..with high priority
   
   TXSTAbits.TXEN = 1;
   
   // Enable interrupt controller
   INTCONbits.GIE = 1;
   INTCONbits.PEIE = 1;

   while(1)
    {
	}//end main
}
/******************************************************************************
 * Function:        static void InitializeSystem(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        InitializeSystem is a centralize initialization routine.
 *                  All required USB initialization routines are called from
 *                  here.
 *
 *                  User application initialization routine should also be
 *                  called from here.                  
 *
 * Note:            None
 *****************************************************************************/
static void InitializeSystem(void)
{
    ADCON1 |= 0x0F;                 // Default all pins to digital
    
    UserInit();                     // See user.c & .h

}//end InitializeSystem

/******************************************************************************
 * Function:        void USBTasks(void)
 *
 * PreCondition:    InitializeSystem has been called.
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        Service loop for USB tasks.
 *
 * Note:            None
 *****************************************************************************/
void USBTasks(void)
{
 
}// end USBTasks

void SetC5   (void) { PORTDbits.RD6=1;}
void ReSetC5 (void) { PORTDbits.RD6=0;}

void SetC4   (void) { PORTBbits.RB0=1;}
void ReSetC4 (void) { PORTBbits.RB0=0;}
 
void SetC3   (void) { PORTBbits.RB1=1;}
void ReSetC3 (void) { PORTBbits.RB1=0;}

void SetC2   (void) { PORTBbits.RB2=1;}
void ReSetC2 (void) { PORTBbits.RB2=0;}

void SetC1   (void) { PORTBbits.RB3=1;}
void ReSetC1 (void) { PORTBbits.RB3=0;}

void SetCLR   (void) { PORTBbits.RB4=1;}
void ReSetCLR (void) { PORTBbits.RB4=0;}

void SetCLK   (void) { PORTDbits.RD5=1;}
void ReSetCLK (void) { PORTDbits.RD5=0;}

void SetDATA   (void) { PORTDbits.RD4=1;}
void ReSetDATA (void) { PORTDbits.RD4=0;}

void writeRow (unsigned char row_selected,unsigned char CHAR)
{
	int data; 
	switch (row_selected) {
		case 0:
			SetC1(); ReSetC2(); ReSetC3(); ReSetC4(); ReSetC5();
			break;
		case 1:
			SetC2(); ReSetC1(); ReSetC3(); ReSetC4(); ReSetC5();
			break;
		case 2:
			SetC3(); ReSetC1(); ReSetC2(); ReSetC4(); ReSetC5();
			break;
		case 3:
			SetC4(); ReSetC1(); ReSetC2(); ReSetC3(); ReSetC5();
			break;
		case 4:
			SetC5(); ReSetC1(); ReSetC2(); ReSetC3(); ReSetC4(); 
			break;
	}


	if (bGraphics)	// graphics mode
		data =CHAR;
	else
	{
		switch (row_selected) {
			case 0:
				data = MatrixTableSeg0 [CHAR-32];
				break;
			case 1:
				data = MatrixTableSeg1 [CHAR-32];
				break;
			case 2:
				data = MatrixTableSeg2 [CHAR-32];
				break;
			case 3:
				data = MatrixTableSeg3 [CHAR-32];
				break;
			case 4:
				data = MatrixTableSeg4 [CHAR-32];
				break;
		}
	}

	if ((data & 0x02) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x04) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x08) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x10) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x20) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x40) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	if ((data & 0x80) >= 1) ReSetDATA(); else SetDATA();
	ReSetCLK(); SetCLK();	// push the bit into the 74H164 

	switch (row_selected) {
		case 0:
			ReSetC1(); SetC2(); SetC3(); SetC4(); SetC5();
			break;
		case 1:
			ReSetC2(); SetC1(); SetC3(); SetC4(); SetC5();
			break;
		case 2:
			ReSetC3(); SetC1(); SetC2(); SetC4(); SetC5();
			break;
		case 3:
			ReSetC4(); SetC1(); SetC2(); SetC3(); SetC5();
			break;
		case 4:
			ReSetC5(); SetC1(); SetC2(); SetC3(); SetC4(); 
			break;
	}


}

void compute_cmd(char Rx_cmd)
{
			RX_cmd = RCREG;  
			while (PIR1bits.RCIF==0);
			RX_data = RCREG;  
			switch (RX_cmd) {
				case SET_CHAR_0:
					CHAR_x[0]=RX_data;
					break;
				case SET_CHAR_1:
					CHAR_x[1]=RX_data;
					break;
				case SET_CHAR_2:
					CHAR_x[2]=RX_data;
					break;
				case SET_CHAR_3:
					CHAR_x[3]=RX_data;
					break;
				case SET_CHAR_4:
					CHAR_x[4]=RX_data;
					break;
				case SET_CHAR_5:
					CHAR_x[5]=RX_data;
					break;
				case SET_CHAR_6:
					CHAR_x[6]=RX_data;
					break;
				case SET_CHAR_7:
					CHAR_x[7]=RX_data;
					break;
	
				case SET_HEURE_DIZAINE :
					HeureDizaine=RX_data;
					break;
				case SET_HEURE_UNIT	:
					HeureUnit=RX_data;
					break;
				case SET_MINUTE_DIZAINE :
					MinuteDizaine=RX_data;
					break;
				case SET_MINUTE_UNIT :
					MinuteUnit=RX_data;
					break;
				case SET_SECONDE_DIZAINE :
					SecondeDizaine=RX_data;
					break;
				case SET_SECONDE_UNIT :	
					SecondeUnit=RX_data;
					break;
				case START_STOP_TIME_COMPUTE :
					bComputeTime = RX_data;
					break;
				case START_STOP_GRAPHICS :
					bGraphics = RX_data;
					index=0; row=0;
					break;	
				case START_WRITE_GRAPHICS :
					Graphics_data_index=0;
					index=0;row=0;
					break;
				case DATA_WRITE_GRAPHICS :
					Graphics[Graphics_data_index++]= RX_data;
					if (Graphics_data_index > (MAX_GRAPHICS-1))	// avoid overflow due to host
						Graphics_data_index = MAX_GRAPHICS-1;
					break;
				case DISPLAY_ON_OFF	:
					for (Graphics_data_index=0;Graphics_data_index < (MAX_GRAPHICS-1);Graphics_data_index++)
								Graphics[Graphics_data_index]= 0;
					Graphics_data_index=0;
					break;
				case CHECK_SYNC :
					if (RX_data==~CHECK_SYNC)
						WriteUSART('1');
					break;
			    case RESET :  // soft reset
					_asm 
						reset
					_endasm
					break;
				case GET_VERSION :
					put_string (Version);
					break;
			}
	
		}
void put_string (char  *str)
{
 int i=0;

	for ( i=0; i < strlen(str);i++)
	{
		while (BusyUSART()); 
		WriteUSART(str[i]);
		for (debug1 =0;debug1<150;)	// delay
							debug1++;
	}

}

//configulation***************************************************************
#pragma config PLLDIV = 6 
#pragma config CPUDIV = OSC1_PLL2 
#pragma config USBDIV = 2 

#pragma config FOSC = HSPLL_HS
//#pragma config FCMEM = OFF 
#pragma config IESO = OFF 

#pragma config PWRT = OFF 
#pragma config BOR = ON 
// debug FCALL #pragma config BORV = 28 
#pragma config VREGEN = ON 

#pragma config WDT = OFF 
#pragma config WDTPS = 1 

#pragma config MCLRE = ON 
#pragma config LPT1OSC = OFF 
#pragma config PBADEN = OFF 
//#pragma config CCP2MX = OFF

#pragma config STVREN = OFF 
#pragma config LVP = OFF 
#pragma config ICPRT = OFF 
#pragma config XINST = OFF 
#pragma config DEBUG = OFF 

#pragma config CP0 = OFF 
#pragma config CPB = OFF 
#pragma config WRT0 = OFF 
#pragma config WRTB = OFF 
#pragma config EBTR0 = OFF 
#pragma config EBTRB = OFF

/** EOF main.c ***************************************************************/

